@@ -1,5 +1,4 @@
 import os
-import tempfile
 import logging
 
 from mkdocs.plugins import BasePlugin
@@ -9,6 +8,7 @@ from mkdocs.structure.pages import Page
 from mkdocs.utils import write_file, copy_file, get_relative_url, warning_filter
 
 from mkdocs_print_site_plugin.renderer import Renderer
+from mkdocs_print_site_plugin.utils import get_theme_name
 
 logger = logging.getLogger("mkdocs.plugins")
 logger.addFilter(warning_filter)
@@ -28,6 +28,7 @@ class PrintSitePlugin(BasePlugin):
         ("add_cover_page", config_options.Type(bool, default=False)),
         ("cover_page_template", config_options.Type(str, default="")),
         ("path_to_pdf", config_options.Type(str, default="")),
+        ("exclude", config_options.Type(list, default=[])),
     )
 
     def on_config(self, config, **kwargs):
@@ -62,14 +63,6 @@ class PrintSitePlugin(BasePlugin):
                     "File not found: %s" % self.cover_page_template_path
                 )
 
-        # Create the (empty) print page file in temp directory
-        tmp_dir = tempfile.gettempdir()
-        tmp_path = os.path.join(tmp_dir, "print_page.md")
-        f = open(tmp_path, "w")
-        f.write("")
-        f.close()
-        assert os.path.exists(tmp_path)
-
         # Add pointer to print-site javascript
         config["extra_javascript"] = ["js/print-site.js"] + config["extra_javascript"]
         config["extra_javascript"] = ["js/print-site-instant-loading.js"] + config[
@@ -80,19 +73,19 @@ class PrintSitePlugin(BasePlugin):
         config["extra_css"] = ["css/print-site.css"] + config["extra_css"]
 
         # Add pointer to theme specific css files
-        file = "print-site-%s.css" % config.get("theme").name
+        file = "print-site-%s.css" % get_theme_name(config)
         if file in os.listdir(os.path.join(HERE, "css")):
             config["extra_css"] = ["css/%s" % file] + config["extra_css"]
         else:
             logger.warning(
                 "[mkdocs-print-site] Theme '%s' not yet supported, which means print margins and page breaks might be off. Feel free to open an issue!"
-                % config.get("theme").name
+                % get_theme_name(config)
             )
 
         # Create MkDocs Page and File instances
         self.print_file = File(
             path="print_page.md",
-            src_dir=tmp_dir,
+            src_dir="",
             dest_dir=config["site_dir"],
             use_directory_urls=config.get("use_directory_urls"),
         )
@@ -161,15 +154,13 @@ class PrintSitePlugin(BasePlugin):
             os.path.join(os.path.join(HERE, "css"), "print-site.css"), css_file_path
         )
         # Add theme CSS file
-        css_file = "print-site-%s.css" % config.get("theme").name
+        css_file = "print-site-%s.css" % get_theme_name(config)
         if css_file in os.listdir(os.path.join(HERE, "css")):
             css_file_path = os.path.join(css_output_base_path, css_file)
             copy_file(os.path.join(os.path.join(HERE, "css"), css_file), css_file_path)
 
         # Determine calls to required javascript functions
         js_calls = ""
-        if config.get("theme").name == "material":
-            js_calls += "change_material_theme('default');"
         if self.config.get("add_table_of_contents"):
             js_calls += "generate_toc();"
 
@@ -180,9 +171,6 @@ class PrintSitePlugin(BasePlugin):
             """
          // Subscribe functions for compatibility 
          // with mkdocs-material's instant loading feature
-         
-         body = document.getElementsByTagName('body')[0];
-         mkdocs_material_site_color_theme = body.getAttribute('data-md-color-scheme');
                     
          if (
             typeof app !== "undefined" && 
@@ -191,12 +179,7 @@ class PrintSitePlugin(BasePlugin):
             app.document$.subscribe(function() {
                 if ( document.querySelector("#print-site-page") !== null ) {
                     %s
-                } else {
-                    // Make sure to change the color theme back!
-                    if ( mkdocs_material_site_color_theme !== null ) {
-                        change_material_theme(mkdocs_material_site_color_theme);   
-                    }
-                }
+            }
             })
          }
         """
